bayesianbandits.api
===================

.. automodule:: bayesianbandits.api

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Agent
      ContextualAgent
      EpsilonGreedy
      ThompsonSampling
      UpperConfidenceBound
   
   

   
   
   



